| na_diagnose | R Documentation |
Provides a summary of missing values for selected columns, including the number and fraction of missing values, the number of consecutive missing runs, and the longest consecutive missing run length (in number of observations).
na_diagnose(data, cols = NULL, date_col = NULL, verbose = FALSE)
data |
A data frame or matrix containing variables to diagnose. |
cols |
The column indices or names of selected variables. If
|
date_col |
Reserved for future use; currently ignored. |
verbose |
Logical; if |
A data frame with columns: variable, n (total
observations), na (number of missing values), na_frac
(missing fraction), na_runs (number of consecutive missing
runs), max_run (longest consecutive missing run length in
number of observations).
na_diagnose(data[1:500, c(1, 4, 17:19)], cols = 3:5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.