| season_flag | R Documentation |
Creates season, month, or quarter indicator from a time column. Useful for grouped analysis and preprocessing by season.
season_flag(data, date_col = NULL, type = c("season", "month", "quarter"),
verbose = FALSE)
data |
A data frame with a time column. |
date_col |
Time column index or name. If |
type |
Type of flag: |
verbose |
Logical; if |
A character vector or factor containing the requested flag.
season_flag(data[1:200, c(1, 4, 17:19)], date_col = 1, type = "season")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.